MemoryExt

Trait MemoryExt 

pub trait MemoryExt {
    // Required methods
    fn shared(&self) -> Information;
    fn text(&self) -> Information;
    fn data(&self) -> Information;
}
Linux-specific extension to process Memory information.

Required Methods

fn shared(&self) -> Information

Returns the amount of memory that could be potentially shared with other processes.

fn text(&self) -> Information

Returns TRS (text resident set) - the amount of memory devoted to executable code.

fn data(&self) -> Information

Returns DRS (data resident set) - the amount of physical memory devoted to other than executable code.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl MemoryExt for Memory

Available on Linux only.