ProcessExt

Trait ProcessExt 

pub trait ProcessExt {
    // Required methods
    fn io_counters(&self) -> BoxFuture<'_, ProcessResult<IoCounters>>;
    fn net_io_counters(&self) -> BoxStream<'_, ProcessResult<IoCounters>>;
}
Linux-specific extension to Process

Required Methods

fn io_counters(&self) -> BoxFuture<'_, ProcessResult<IoCounters>>

Returns future which resolves into process IO counters.

Since -> impl Trait is not allowed yet in the trait methods, this method returns boxed Future. This behavior will change later.

fn net_io_counters(&self) -> BoxStream<'_, ProcessResult<IoCounters>>

Returns stream which yield this process IO counters for each network interface.

Since -> impl Trait is not allowed yet in the trait methods, this method returns boxed Stream. This behavior will change later.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ProcessExt for Process

Available on Linux only.