[−][src]Crate heim_process
System processes information.
Modules
| os | OS-specific extensions. |
Structs
| Command | Process command line. |
| CommandIter | Iterator over process command line arguments. |
| CpuTime | Accumulated CPU time for specific process. |
| CpuUsage | Process CPU usage measurement. |
| Environment | Process environment variables. |
| EnvironmentIter | A non-consuming iterator for the process environment variables. |
| IntoEnvironmentIter | An iterator that moves out from the process environment variables. |
| IoCounters | Network device I/O counters. |
| Memory | Memory information about the process. |
| Process | System process. |
Enums
| ProcessError | Error which might happen during the process information fetching. |
| Status | Process status. |
Functions
| current | Returns the |
| get | Loads the process information with |
| pid_exists | Checks if the process with given |
| pids | Returns a stream over the Pids of the processes currently running in the system. |
| processes | Returns a stream over the currently running processes. |
Type Definitions
| Pid | Process identifier type. |
| ProcessResult | A specialized |
| Time |
|